"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var ogs = __importStar(require("object-graph-streamer"));
var simpleEnvelope_1 = require("./simpleEnvelope");
// import { Envelope } from "../schema/envelope";
var envelope_1 = require("./lang/ts/envelope");
beforeAll(function () {
    // Lock Time
    jest.useFakeTimers("modern");
    jest.setSystemTime(new Date(1624140000000));
    // jest.spyOn(Date, 'now').mockImplementation(() => 1487076708000);
});
// it("test simple sha256 creation", () => {
//   expect.assertions(2);
//   const expectedHash =
//     "3f0a377ba0a4a460ecb616f6507ce0d8cfa3e704025d4fda3ed0c5ca05468728";
//   expect(hashIt("test message")).toEqual(expectedHash);
//   expect(hashIt("t\u0065\u0073t m\u0065\u0073\u0073ag\u0065")).toEqual(
//     expectedHash
//   );
// });
it("test simple hash", function () {
    // expect.assertions(3);
    var hashC = new ogs.HashCollector();
    ogs.objectGraphStreamer({
        kind: "test",
        data: {
            name: "object",
            date: "2021-05-20",
        },
    }, function (sval) { return hashC.append(sval); });
    expect(hashC.digest()).toBe("5zWhdtvKuGob1FbW9vUGPQKobcLtYYr5wU8AxQRVraeB");
});
it("test serialization", function () {
    var message = {
        id: "1624140000000-4a2a6fb97b3afe6a7ca4c13457c441664c7f6a6c2ea7782e1f2dea384cf97cb8",
        src: "test case",
        data: {
            kind: "test",
            data: { name: "object", date: "2021-05-20" },
        },
        dst: [],
        t: new Date(444),
        ttl: 10,
    };
    var expected = {
        stringify: '{"data":{"data":{"date":"2021-05-20","name":"object"},"kind":"test"},"dst":[],"id":"1624140000000-4a2a6fb97b3afe6a7ca4c13457c441664c7f6a6c2ea7782e1f2dea384cf97cb8","src":"test case","t":444,"ttl":10,"v":"A"}',
    };
    expect((0, simpleEnvelope_1.simpleEnvelope)(message).asJson()).toEqual(expected.stringify);
});
it("test serialization with hash", function () {
    var message = {
        src: "test case",
        data: {
            kind: "test",
            data: { name: "object", date: "2021-05-20" },
        },
        dst: [],
        // t: new Date(444),
        ttl: 10,
    };
    var expected = {
        stringify: '{"data":{"data":{"date":"2021-05-20","name":"object"},"kind":"test"},"dst":[],"id":"1624140000000-BbYxQMurpUmj1W6E4EwYM79Rm3quSz1wwtNZDSsFt1bp","src":"test case","t":1624140000000,"ttl":10,"v":"A"}',
    };
    expect((0, simpleEnvelope_1.simpleEnvelope)(message).asJson()).toEqual(expected.stringify);
});
it("test serialization with intend", function () {
    var message = {
        src: "test case",
        data: {
            kind: "test",
            data: { name: "object", date: "2021-05-20" },
        },
        dst: [],
        // t: new Date(444),
        ttl: 10,
        jsonProp: {
            indent: 2,
        },
    };
    var expected = {
        stringify: JSON.stringify(JSON.parse('{"data":{"data":{"date":"2021-05-20","name":"object"},"kind":"test"},"dst":[],"id":"1624140000000-BbYxQMurpUmj1W6E4EwYM79Rm3quSz1wwtNZDSsFt1bp","src":"test case","t":1624140000000,"ttl":10,"v":"A"}'), null, 2),
    };
    expect((0, simpleEnvelope_1.simpleEnvelope)(message).asJson()).toEqual(expected.stringify);
});
it("missing data in envelope", function () {
    var payt = envelope_1.Convert.toPayload(JSON.stringify({
        kind: "kind",
        data: { y: 4 },
    }));
    var message = {
        src: "test case",
        data: payt,
    };
    var ref = envelope_1.Convert.toEnvelope((0, simpleEnvelope_1.simpleEnvelope)(message).asJson());
    expect((0, simpleEnvelope_1.simpleEnvelope)(ref).asEnvelope().data).toEqual(message.data);
});
it("simpleEnvelope with id", function () {
    var payt = envelope_1.Convert.toPayload(JSON.stringify({
        kind: "kind",
        data: { y: 4 },
    }));
    var message = {
        src: "test case",
        data: payt,
        id: "myId",
        idGenerator: simpleEnvelope_1.hashIdGenerator,
    };
    var ref = envelope_1.Convert.toEnvelope((0, simpleEnvelope_1.simpleEnvelope)(message).asJson());
    expect((0, simpleEnvelope_1.simpleEnvelope)(ref).asEnvelope().id).toEqual("myId");
});
it("simpleEnvelope with default tHashGenerator", function () {
    var payt = envelope_1.Convert.toPayload(JSON.stringify({
        kind: "kind",
        data: { y: 4 },
    }));
    var message = {
        src: "test case",
        data: payt,
        t: 123,
        idGenerator: undefined,
    };
    var ref = envelope_1.Convert.toEnvelope((0, simpleEnvelope_1.simpleEnvelope)(message).asJson());
    expect((0, simpleEnvelope_1.simpleEnvelope)(ref).asEnvelope().id).toEqual("123-GUKeStj4aGQRju7p2Dzf31Qi2d2MVuRCw68H1c8gMCnQ");
});
it("simpleEnvelope with custom id generator", function () {
    var payt = envelope_1.Convert.toPayload(JSON.stringify({
        kind: "kind",
        data: { y: 4 },
    }));
    var message = {
        src: "test case",
        data: payt,
        idGenerator: simpleEnvelope_1.hashIdGenerator,
    };
    var ref = envelope_1.Convert.toEnvelope((0, simpleEnvelope_1.simpleEnvelope)(message).asJson());
    expect((0, simpleEnvelope_1.simpleEnvelope)(ref).asEnvelope().id).toEqual("GUKeStj4aGQRju7p2Dzf31Qi2d2MVuRCw68H1c8gMCnQ");
});
afterAll(function () {
    // Unlock Time
    jest.useRealTimers();
});
//# sourceMappingURL=simpleEnvelope.test.js.map